//
// FlybitsSDK.h
// Copyright (c) :YEAR: Flybits (http://flybits.com)
//
// Permission to use this codebase and all related and dependent interfaces
// are granted as bound by the licensing agreement between Flybits and
// :COMPANY_NAME: effective :EFFECTIVE_DATE:.
//
// Flybits Framework version :VERSION:
// Built: :BUILD_DATE:
//

@import UIKit;



//! Project version number for FlybitsSDK.
FOUNDATION_EXPORT double FlybitsSDKVersionNumber;

//! Project version string for FlybitsSDK.
FOUNDATION_EXPORT const unsigned char FlybitsSDKVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <FlybitsSDK/PublicHeader.h>
